@@ -1,18 +1,20 @@
-use crate::filter::LogLineFilter;
-use crate::flexi_logger::FlexiLogger;
-use crate::formats::default_format;
 #[cfg(feature = "atty")]
 use crate::formats::AdaptiveFormat;
 #[cfg(feature = "specfile_without_notification")]
 use crate::logger_handle::LogSpecSubscriber;
-use crate::primary_writer::PrimaryWriter;
 #[cfg(feature = "specfile")]
 use crate::util::{eprint_err, ERRCODE};
-use crate::writers::{FileLogWriter, FileLogWriterBuilder, LogWriter};
-use crate::WriteMode;
+
 use crate::{
+    filter::LogLineFilter,
+    flexi_logger::FlexiLogger,
+    formats::default_format,
+    now_local,
+    primary_writer::PrimaryWriter,
+    util::set_error_channel,
+    writers::{FileLogWriter, FileLogWriterBuilder, LogWriter},
     Cleanup, Criterion, FileSpec, FlexiLoggerError, FormatFunction, LogSpecification, LoggerHandle,
-    Naming,
+    Naming, WriteMode,
 };
 
 #[cfg(feature = "specfile")]
@@ -69,6 +71,7 @@ pub struct Logger {
     flwb: FileLogWriterBuilder,
     other_writers: HashMap<String, Box<dyn LogWriter>>,
     filter: Option<Box<dyn LogLineFilter + Send + Sync>>,
+    error_channel: ErrorChannel,
 }
 
 enum LogTarget {
@@ -119,6 +122,9 @@ impl Logger {
     }
 
     fn from_spec_and_errs(spec: LogSpecification) -> Self {
+        // make sure the lazy_static in this function is filled as early as possible:
+        let _ = now_local();
+
         #[cfg(feature = "colors")]
         #[cfg(windows)]
         {
@@ -157,6 +163,7 @@ impl Logger {
             flwb: FileLogWriter::builder(FileSpec::default()),
             other_writers: HashMap::<String, Box<dyn LogWriter>>::new(),
             filter: None,
+            error_channel: ErrorChannel::default(),
         }
     }
 }
@@ -502,6 +509,41 @@ impl Logger {
         self.flwb = self.flwb.use_windows_line_ending();
         self
     }
+
+    /// Define the output channel for `flexi_logger`'s own error messages.
+    ///
+    /// These are only written if `flexi_logger` cannot do what it is supposed to do,
+    /// so under normal circumstances no single message shuld appear.
+    ///
+    /// By default these error messages are printed to `stderr`.
+    #[must_use]
+    pub fn error_channel(mut self, error_channel: ErrorChannel) -> Self {
+        self.error_channel = error_channel;
+        self
+    }
+}
+
+/// Enum for defining the output channel for `flexi_logger`'s own error messages.
+///
+/// These are only written if `flexi_logger` cannot do what it is supposed to do,
+/// so under normal circumstances no single message shuld appear.
+///
+/// By default these error messages are printed to `stderr`.
+#[derive(Debug)]
+pub enum ErrorChannel {
+    /// Write `flexi_logger`'s own error messages to `stderr`.
+    StdErr,
+    /// Write `flexi_logger`'s own error messages to `stdout`.
+    StdOut,
+    /// Write `flexi_logger`'s own error messages to the specified file.
+    File(PathBuf),
+    /// Don't write `flexi_logger`'s own error messages.
+    DevNull,
+}
+impl Default for ErrorChannel {
+    fn default() -> Self {
+        ErrorChannel::StdErr
+    }
 }
 
 /// Alternative set of methods to control the behavior of the Logger.
@@ -661,6 +703,7 @@ impl Logger {
 
         let max_level = self.spec.max_level();
         let a_l_spec = Arc::new(RwLock::new(self.spec));
+        set_error_channel(self.error_channel);
 
         let flexi_logger = FlexiLogger::new(
             Arc::clone(&a_l_spec),
