@@ -1,15 +1,15 @@
-use crate::deferred_now::now_local_or_utc;
-use crate::util::{eprint_err, ERRCODE};
-use crate::FileSpec;
-use crate::{Age, Cleanup, Criterion, FlexiLoggerError, Naming};
+use super::{Config, RotationConfig};
+use crate::{
+    now_local,
+    util::{eprint_err, ERRCODE},
+    Age, Cleanup, Criterion, FileSpec, FlexiLoggerError, Naming,
+};
 use std::cmp::max;
 use std::fs::{File, OpenOptions};
 use std::io::{BufRead, BufReader, BufWriter, Write};
 use std::ops::Add;
 use std::path::{Path, PathBuf};
-use time::{format_description, OffsetDateTime};
-
-use super::{Config, RotationConfig};
+use time::{format_description::FormatItem, macros::format_description, OffsetDateTime};
 
 const CURRENT_INFIX: &str = "_rCURRENT";
 fn number_infix(idx: u32) -> String {
@@ -65,7 +65,7 @@ impl RotationState {
     }
 
     fn age_rotation_necessary(&self, age: Age) -> bool {
-        let now = now_local_or_utc();
+        let now = now_local();
         match age {
             Age::Day => {
                 self.created_at.year() != now.year()
@@ -578,16 +578,13 @@ fn rotate_output_file_to_date(
     creation_date: &OffsetDateTime,
     config: &Config,
 ) -> Result<(), std::io::Error> {
-    const TS_S: &str = "_r[year]-[month]-[day]_[hour]-[minute]-[second]";
-    lazy_static::lazy_static! {
-    static ref TS: Vec<format_description::FormatItem<'static>>
-    = format_description::parse(TS_S).unwrap(/*ok*/);
-    }
+    const INFIX_DATE: &[FormatItem<'static>] =
+        format_description!("_r[year]-[month]-[day]_[hour]-[minute]-[second]");
 
     let current_path = config.file_spec.as_pathbuf(Some(CURRENT_INFIX));
     let mut rotated_path = config
         .file_spec
-        .as_pathbuf(Some(&creation_date.format(&TS).unwrap(/*ok*/)));
+        .as_pathbuf(Some(&creation_date.format(INFIX_DATE).unwrap()));
 
     // Search for rotated_path as is and for restart-siblings;
     // if any exists, find highest restart and add 1, else continue without restart
@@ -617,9 +614,9 @@ fn rotate_output_file_to_date(
         while (*rotated_path).exists() {
             rotated_path = config.file_spec.as_pathbuf(Some(
                 &creation_date
-                    .format(&TS)
-                    .unwrap(/*ok*/)
-                    .add(&format!(".restart-{:04}", number)),
+                .format(INFIX_DATE)
+                .unwrap(/*ok*/)
+                .add(&format!(".restart-{:04}", number)),
             ));
             number += 1;
         }
@@ -683,7 +680,7 @@ fn get_creation_date(path: &Path) -> OffsetDateTime {
 }
 
 fn get_fake_creation_date() -> OffsetDateTime {
-    now_local_or_utc()
+    now_local()
 }
 
 #[cfg(not(any(target_os = "windows", target_os = "linux")))]
